==> nextcloud-11.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/oc.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galariá",
    "Aborting preview. Could not find the file" : "Interrupcion de la previsualizacion. Lo fichièr es introbable.",
    "Could not move \"{file}\", target exists" : "Impossible de desplaçar \"{file}\", la cibla existís",
    "Could not move \"{file}\"" : "Impossible de desplaçar \"{file}\"",
    "Gallery view" : "Vista en galariá",
    "Could not load the description" : "Impossible de cargar la descripcion",
    "Could not load the description: " : "Impossible de cargar la descripcion :",
    "Copyright" : "Drech d'autor",
    "Could not load the copyright notice: " : "Impossible de cargar l'avís de drech d'autor :",
    "Copyright notice" : "Avís de drech d'autor",
    "Link to copyright document" : "Ligam cap a l'avís de drech d'autor complet",
    "This application may not work properly on your browser." : "Es possible qu'aquesta aplicacion foncione pas corrèctament dins vòstre navigador.",
    "For an improved experience, please install one of the following alternatives" : "Per una melhora experiéncia, installatz una de las alternativas seguentas",
    "Your browser is not supported!" : "Vòstre navigador es pas pres en carga !",
    "please install one of the following alternatives" : "Installatz una de las alternativas seguentas",
    "Album cannot be shown" : "Impossible d'afichar l'album",
    "No media files found" : "Cap de fichièr mèdia pas trobat",
    "Upload pictures in the files app to display them here" : "Apondètz d'imatges dins l'aplicacion Fichièrs e apareisseràn aicí",
    "Configuration error" : "Error de configuracion",
    "New" : "Novèl",
    "Error loading slideshow template" : "Error al moment del telecargament del modèl de diaporama ",
    "Next" : "Seguent",
    "Play" : "Aviar",
    "Pause" : "Pausa",
    "Previous" : "Precedent",
    "Close" : "Tampar",
    "Download" : "Telecargar",
    "Toggle background" : "Activar/Desactivar lo rèire plan",
    "Delete" : "Suprimir",
    "Could not create file \"{file}\" because it already exists" : "Impossible de crear lo fichièr \"{file}\" perque existís ja",
    "Could not create file \"{file}\"" : "Impossible de crear lo fichièr \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" es pas un nom de fichièr valid.",
    "File name cannot be empty." : "Lo nom de fichièr pòt pas èsser void.",
    "Upload" : "Cargament",
    "Error" : "Error",
    "Error while sharing" : "Error al moment de la mesa en partiment",
    "Error while unsharing" : "Error al moment de l'anullacion del partiment",
    "Error while changing permissions" : "Error al moment del cambiament de las permissions",
    "Shared with you and the group {group} by {owner}" : "Partejat amb vos e lo grop {group} per {owner}",
    "Shared with you by {owner}" : "Partejat amb vos per {owner}",
    "Share with users or groups …" : "Partejar amb d'utilizaires o gropes...",
    "Share with users, groups or remote users …" : "Partejar amb d'utilizaires, gropes, o utilizaires distants",
    "Share" : "Partejar",
    "Share link" : "Partejar lo ligam",
    "The public link will expire no later than {days} days after it is created" : "Aqueste ligam public expirarà al mai tard {days} jorns aprèp sa creacion.",
    "Link" : "Ligam",
    "Password protect" : "Protegir per un senhal",
    "Password" : "Senhal",
    "Choose a password for the public link" : "Causissètz un senhal pel ligam public",
    "Allow editing" : "Permetre la modificacion",
    "Email link to person" : "Mandar lo ligam per corrièl",
    "Send" : "Mandar",
    "Set expiration date" : "Especificar una data d'expiracion",
    "Expiration" : "Expiration",
    "Expiration date" : "Data d'expiracion",
    "An error occured. Please try again" : "Una error s'es produsida. Mercé d'ensajar tornamai",
    "Adding user..." : "Apondon de l'utilizaire...",
    "group" : "grop",
    "remote" : "distant",
    "Resharing is not allowed" : "Lo repartiment es pas autorizat",
    "Unshare" : "Partejar pas mai",
    "notify by email" : "notificar per corrièl",
    "can share" : "pòt partejar",
    "can edit" : "pòt modificar",
    "access control" : "contraròtle d'accès",
    "create" : "crear",
    "change" : "modificacion",
    "delete" : "suprimir",
    "Password protected" : "Protegit per senhal",
    "Error unsetting expiration date" : "Error al moment de la supression de la data d'expiracion",
    "Error setting expiration date" : "Error al moment de l'especificacion de la data d'expiracion",
    "Sending ..." : "Mandadís…",
    "Email sent" : "Corrièl mandat",
    "Warning" : "Atencion",
    "This share is password-protected" : "Aqueste partiment es protegit per un senhal",
    "The password is wrong. Try again." : "Lo senhal es incorrècte. Ensajatz tornamai.",
    "Sort by date" : "Triar per data",
    "Sort by name" : "Triar per nom",
    "Cancel upload" : "Anullar lo mandadís",
    "Album information" : "Informacions sus l'album",
    "File list" : "Lista dels fichièrs",
    "Sorry, this file could not be found." : "O planhèm, aqueste fichièr a pas pogut èsser trobat.",
    "Reasons might be:" : "Las rasons pòdon èsser :",
    "the wrong file ID was provided" : "identificant de fichièr pas valable",
    "the file was removed" : "lo fichièr es estat suprimit",
    "the file is corrupt" : "lo fichièr es corromput",
    "the encryption key is missing" : "la clau de chiframent es mancanta",
    "Here is the error message returned by the server: " : "Messatge d'error renviat pel servidor :",
    "Sorry, but the server could not fulfill your request." : "O planhèm, lo servidor pòt pas satisfar vòstra requèsta.",
    "Possible reasons for the problem:" : "Rasons possiblas del problèma :",
    "a conflicting app was installed" : "una aplicacion incompatibla es estada installada",
    "a required component is missing or was disconnected" : "un component requesit es mancant o es estat desconnectat",
    "the filesystem is not readable" : "lo sistèma de fichièrs es pas legible",
    "For more information, please contact your friendly ownCloud administrator." : "Per mai d'informacions, contactatz vòstre administrator ownCloud.",
    "Sorry, this link doesn't seem to work anymore." : "O planhèm, sembla qu'aqueste ligam fonciona pas mai.",
    "the item was removed" : "l'element es estat suprimit",
    "the link has expired" : "lo ligam a expirat",
    "sharing is disabled" : "lo partiment es desactivat",
    "For more information, please ask the person who has sent you this link." : "Per mai d'informacions, contactatz la persona que vos a mandat aqueste ligam.",
    "Picture view" : "Visualizacion de l'imatge"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/oc.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galariá",
    "Aborting preview. Could not find the file" : "Interrupcion de la previsualizacion. Lo fichièr es introbable.",
    "Could not move \"{file}\", target exists" : "Impossible de desplaçar \"{file}\", la cibla existís",
    "Could not move \"{file}\"" : "Impossible de desplaçar \"{file}\"",
    "Could not load the description" : "Impossible de cargar la descripcion",
    "Could not load the description: " : "Impossible de cargar la descripcion :",
    "Copyright" : "Drech d'autor",
    "Could not load the copyright notice: " : "Impossible de cargar l'avís de drech d'autor :",
    "Copyright notice" : "Avís de drech d'autor",
    "Link to copyright document" : "Ligam cap a l'avís de drech d'autor complet",
    "This application may not work properly on your browser." : "Es possible qu'aquesta aplicacion foncione pas corrèctament dins vòstre navigador.",
    "For an improved experience, please install one of the following alternatives" : "Per una melhora experiéncia, installatz una de las alternativas seguentas",
    "Your browser is not supported!" : "Vòstre navigador es pas pres en carga !",
    "please install one of the following alternatives" : "Installatz una de las alternativas seguentas",
    "Album cannot be shown" : "Impossible d'afichar l'album",
    "No media files found" : "Cap de fichièr mèdia pas trobat",
    "Configuration error" : "Error de configuracion",
    "New" : "Novèl",
    "Error loading slideshow template" : "Error al moment del telecargament del modèl de diaporama ",
    "Next" : "Seguent",
    "Play" : "Aviar",
    "Pause" : "Pausa",
    "Previous" : "Precedent",
    "Close" : "Tampar",
    "Download" : "Telecargar",
    "Toggle background" : "Activar/Desactivar lo rèire plan",
    "Delete" : "Suprimir",
    "Could not create file \"{file}\" because it already exists" : "Impossible de crear lo fichièr \"{file}\" perque existís ja",
    "Could not create file \"{file}\"" : "Impossible de crear lo fichièr \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" es pas un nom de fichièr valid.",
    "File name cannot be empty." : "Lo nom de fichièr pòt pas èsser void.",
    "Upload" : "Cargament",
    "Error" : "Error",
    "Error while sharing" : "Error al moment de la mesa en partiment",
    "Error while unsharing" : "Error al moment de l'anullacion del partiment",
    "Error while changing permissions" : "Error al moment del cambiament de las permissions",
    "Shared with you and the group {group} by {owner}" : "Partejat amb vos e lo grop {group} per {owner}",
    "Shared with you by {owner}" : "Partejat amb vos per {owner}",
    "Share with users or groups …" : "Partejar amb d'utilizaires o gropes...",
    "Share with users, groups or remote users …" : "Partejar amb d'utilizaires, gropes, o utilizaires distants",
    "Share" : "Partejar",
    "Share link" : "Partejar lo ligam",
    "The public link will expire no later than {days} days after it is created" : "Aqueste ligam public expirarà al mai tard {days} jorns aprèp sa creacion.",
    "Link" : "Ligam",
    "Password protect" : "Protegir per un senhal",
    "Password" : "Senhal",
    "Choose a password for the public link" : "Causissètz un senhal pel ligam public",
    "Allow editing" : "Permetre la modificacion",
    "Email link to person" : "Mandar lo ligam per corrièl",
    "Send" : "Mandar",
    "Set expiration date" : "Especificar una data d'expiracion",
    "Expiration" : "Expiration",
    "Expiration date" : "Data d'expiracion",
    "An error occured. Please try again" : "Una error s'es produsida. Mercé d'ensajar tornamai",
    "Adding user..." : "Apondon de l'utilizaire...",
    "group" : "grop",
    "remote" : "distant",
    "Resharing is not allowed" : "Lo repartiment es pas autorizat",
    "Unshare" : "Partejar pas mai",
    "notify by email" : "notificar per corrièl",
    "can share" : "pòt partejar",
    "can edit" : "pòt modificar",
    "access control" : "contraròtle d'accès",
    "create" : "crear",
    "change" : "modificacion",
    "delete" : "suprimir",
    "Password protected" : "Protegit per senhal",
    "Error unsetting expiration date" : "Error al moment de la supression de la data d'expiracion",
    "Error setting expiration date" : "Error al moment de l'especificacion de la data d'expiracion",
    "Sending ..." : "Mandadís…",
    "Email sent" : "Corrièl mandat",
    "Warning" : "Atencion",
    "This share is password-protected" : "Aqueste partiment es protegit per un senhal",
    "The password is wrong. Try again." : "Lo senhal es incorrècte. Ensajatz tornamai.",
    "Sort by date" : "Triar per data",
    "Sort by name" : "Triar per nom",
    "Cancel upload" : "Anullar lo mandadís",
    "Album information" : "Informacions sus l'album",
    "File list" : "Lista dels fichièrs",
    "Sorry, this file could not be found." : "O planhèm, aqueste fichièr a pas pogut èsser trobat.",
    "Reasons might be:" : "Las rasons pòdon èsser :",
    "the wrong file ID was provided" : "identificant de fichièr pas valable",
    "the file was removed" : "lo fichièr es estat suprimit",
    "the file is corrupt" : "lo fichièr es corromput",
    "the encryption key is missing" : "la clau de chiframent es mancanta",
    "Here is the error message returned by the server: " : "Messatge d'error renviat pel servidor :",
    "Sorry, but the server could not fulfill your request." : "O planhèm, lo servidor pòt pas satisfar vòstra requèsta.",
    "Possible reasons for the problem:" : "Rasons possiblas del problèma :",
    "a conflicting app was installed" : "una aplicacion incompatibla es estada installada",
    "a required component is missing or was disconnected" : "un component requesit es mancant o es estat desconnectat",
    "the filesystem is not readable" : "lo sistèma de fichièrs es pas legible",
    "Sorry, this link doesn't seem to work anymore." : "O planhèm, sembla qu'aqueste ligam fonciona pas mai.",
    "the item was removed" : "l'element es estat suprimit",
    "the link has expired" : "lo ligam a expirat",
    "sharing is disabled" : "lo partiment es desactivat",
    "For more information, please ask the person who has sent you this link." : "Per mai d'informacions, contactatz la persona que vos a mandat aqueste ligam.",
    "Picture view" : "Visualizacion de l'imatge",
    "Gallery view" : "Vista en galariá"
},
"nplurals=2; plural=(n > 1);");
